@@ -7,6 +7,7 @@ from .shared import validate_list_term_percent, validate_linked_source_privacy,
 from .practice import validate_cropResidueManagement
 from .product import validate_economicValueShare, validate_value as validate_product_value
 from .data_completeness import validate_dataCompleteness
+from .transformation import validate_previous_transformation
 
 
 SITE_TYPES_1ha = [
@@ -128,4 +129,9 @@ def validate_cycle(cycle: dict, nodes=[]):
         validate_cropResidueManagement(cycle.get('practices'))
     ] if 'practices' in cycle else []) + _flatten([
         validate_functionalUnitMeasure(cycle, site)
-    ] if 'functionalUnitMeasure' in cycle and site else [])
+    ] if 'functionalUnitMeasure' in cycle and site else []) + _flatten([
+        validate_previous_transformation(cycle.get('transformations')),
+        validate_list_duplicates(cycle, 'transformations', [
+            'term.@id'
+        ])
+    ] if 'transformations' in cycle else [])
