@@ -4,7 +4,7 @@ import re
 from hestia_earth.validation.geojson import _get_geojson_area
 from hestia_earth.validation.gee import _get_region_id
 from hestia_earth.validation.utils import _filter_list_errors, _next_error, _same_properties, _value_average
-from hestia_earth.validation.utils import _find_linked_node
+from hestia_earth.validation.utils import _find_linked_node, _list_has_props
 
 
 def validate_dates(node: dict):
@@ -26,6 +26,21 @@ def validate_list_dates(node: dict, list_key: str):
     return _filter_list_errors(list(map(validate, enumerate(node.get(list_key, [])))))
 
 
+def validate_list_dates_length(node: dict, list_key: str):
+    def validate(values):
+        value = values[1]
+        index = values[0]
+        expected = len(value.get('value'))
+        return len(value.get('dates')) == expected or {
+            'level': 'error',
+            'dataPath': f".{list_key}[{index}].dates",
+            'message': 'must contain ' + str(expected) + (' values' if expected > 1 else ' value')
+        }
+
+    results = list(map(validate, enumerate(_list_has_props(node.get(list_key), ['dates', 'value']))))
+    return next((x for x in results if x is not True), True)
+
+
 def _compare_min_max(value1, value2): return value1 <= value2
 
 
