@@ -4,7 +4,8 @@ import json
 from tests.utils import fixtures_path
 from hestia_earth.validation.validators.shared import validate_dates, validate_list_dates, validate_list_duplicates, \
     validate_list_min_max, validate_country, validate_region, validate_area, validate_coordinates, \
-    need_validate_coordinates, validate_list_term_percent, validate_empty_fields, validate_linked_source_privacy
+    need_validate_coordinates, validate_list_term_percent, validate_empty_fields, validate_linked_source_privacy, \
+    validate_list_dates_length
 
 
 class TestValidatorsShared(unittest.TestCase):
@@ -27,6 +28,28 @@ class TestValidatorsShared(unittest.TestCase):
             'endDate': '2020-01-01'
         }), False)
 
+    def test_validate_list_dates_length_valid(self):
+        cycle = {
+            'emissions': [{
+                'value': [1],
+                'dates': [1]
+            }]
+        }
+        self.assertEqual(validate_list_dates_length(cycle, 'emissions'), True)
+
+    def test_validate_list_dates_length_invalid(self):
+        cycle = {
+            'emissions': [{
+                'value': [1],
+                'dates': [1, 2]
+            }]
+        }
+        self.assertEqual(validate_list_dates_length(cycle, 'emissions'), {
+            'level': 'error',
+            'dataPath': '.emissions[0].dates',
+            'message': 'must contain 1 value'
+        })
+
     def test_validate_emissions_dates_valid(self):
         node = {
             'list': [{
